import { AcceptInviteRequest, APIErrors, APIMeta, BulkCreateEventRequest, BulkCreateEventResponse, CancelEventRequest, CreateAPITokenRequest, CreateAPITokenResponse, CreateEventRequest, CreateSNSIntegrationRequest, CreateTenantAlertEmailGroupRequest, CreateTenantInviteRequest, CreateTenantRequest, Event, EventData, EventKey, EventKeyList, EventList, EventOrderByDirection, EventOrderByField, EventSearch, ListAPIMetaIntegration, ListAPITokensResponse, ListSlackWebhooks, ListSNSIntegrations, LogLineLevelField, LogLineList, LogLineOrderByDirection, LogLineOrderByField, LogLineSearch, RateLimitList, RateLimitOrderByDirection, RateLimitOrderByField, RejectInviteRequest, ReplayEventRequest, ReplayWorkflowRunsRequest, ReplayWorkflowRunsResponse, RerunStepRunRequest, SNSIntegration, StepRun, StepRunArchiveList, StepRunEventList, Tenant, TenantAlertEmailGroup, TenantAlertEmailGroupList, TenantAlertingSettings, TenantInvite, TenantInviteList, TenantMember, TenantMemberList, TenantQueueMetrics, TenantResourcePolicy, TenantStepRunQueueMetrics, TriggerWorkflowRunRequest, UpdateTenantAlertEmailGroupRequest, UpdateTenantInviteRequest, UpdateTenantRequest, UpdateWorkerRequest, User, UserChangePasswordRequest, UserLoginRequest, UserRegisterRequest, UserTenantMembershipsList, WebhookWorkerCreated, WebhookWorkerCreateRequest, WebhookWorkerListResponse, WebhookWorkerRequestListResponse, Worker, WorkerList, Workflow, WorkflowID, WorkflowKindList, WorkflowList, WorkflowMetrics, WorkflowRun, WorkflowRunList, WorkflowRunOrderByDirection, WorkflowRunOrderByField, WorkflowRunsCancelRequest, WorkflowRunShape, WorkflowRunsMetrics, WorkflowRunStatus, WorkflowRunStatusList, WorkflowUpdateRequest, WorkflowVersion, WorkflowWorkersCount } from './data-contracts';
import { HttpClient, RequestParams } from './http-client';
export declare class Api<SecurityDataType = unknown> extends HttpClient<SecurityDataType> {
    /**
     * @description Gets the readiness status
     *
     * @tags Healthcheck
     * @name ReadinessGet
     * @summary Get readiness
     * @request GET:/api/ready
     */
    readinessGet: (params?: RequestParams) => Promise<import("axios").AxiosResponse<void, any>>;
    /**
     * @description Gets the liveness status
     *
     * @tags Healthcheck
     * @name LivenessGet
     * @summary Get liveness
     * @request GET:/api/live
     */
    livenessGet: (params?: RequestParams) => Promise<import("axios").AxiosResponse<void, any>>;
    /**
     * @description Gets metadata for the Hatchet instance
     *
     * @tags Metadata
     * @name MetadataGet
     * @summary Get metadata
     * @request GET:/api/v1/meta
     */
    metadataGet: (params?: RequestParams) => Promise<import("axios").AxiosResponse<APIMeta, any>>;
    /**
     * @description Gets metadata for the Hatchet cloud instance
     *
     * @tags Metadata
     * @name CloudMetadataGet
     * @summary Get cloud metadata
     * @request GET:/api/v1/cloud/metadata
     */
    cloudMetadataGet: (params?: RequestParams) => Promise<import("axios").AxiosResponse<APIErrors, any>>;
    /**
     * @description List all integrations
     *
     * @tags Metadata
     * @name MetadataListIntegrations
     * @summary List integrations
     * @request GET:/api/v1/meta/integrations
     * @secure
     */
    metadataListIntegrations: (params?: RequestParams) => Promise<import("axios").AxiosResponse<ListAPIMetaIntegration, any>>;
    /**
     * @description Logs in a user.
     *
     * @tags User
     * @name UserUpdateLogin
     * @summary Login user
     * @request POST:/api/v1/users/login
     */
    userUpdateLogin: (data: UserLoginRequest, params?: RequestParams) => Promise<import("axios").AxiosResponse<User, any>>;
    /**
     * @description Starts the OAuth flow
     *
     * @tags User
     * @name UserUpdateGoogleOauthStart
     * @summary Start OAuth flow
     * @request GET:/api/v1/users/google/start
     */
    userUpdateGoogleOauthStart: (params?: RequestParams) => Promise<import("axios").AxiosResponse<any, any>>;
    /**
     * @description Completes the OAuth flow
     *
     * @tags User
     * @name UserUpdateGoogleOauthCallback
     * @summary Complete OAuth flow
     * @request GET:/api/v1/users/google/callback
     */
    userUpdateGoogleOauthCallback: (params?: RequestParams) => Promise<import("axios").AxiosResponse<any, any>>;
    /**
     * @description Starts the OAuth flow
     *
     * @tags User
     * @name UserUpdateGithubOauthStart
     * @summary Start OAuth flow
     * @request GET:/api/v1/users/github/start
     */
    userUpdateGithubOauthStart: (params?: RequestParams) => Promise<import("axios").AxiosResponse<any, any>>;
    /**
     * @description Completes the OAuth flow
     *
     * @tags User
     * @name UserUpdateGithubOauthCallback
     * @summary Complete OAuth flow
     * @request GET:/api/v1/users/github/callback
     */
    userUpdateGithubOauthCallback: (params?: RequestParams) => Promise<import("axios").AxiosResponse<any, any>>;
    /**
     * @description Starts the OAuth flow
     *
     * @tags User
     * @name UserUpdateSlackOauthStart
     * @summary Start OAuth flow
     * @request GET:/api/v1/tenants/{tenant}/slack/start
     * @secure
     */
    userUpdateSlackOauthStart: (tenant: string, params?: RequestParams) => Promise<import("axios").AxiosResponse<any, any>>;
    /**
     * @description Completes the OAuth flow
     *
     * @tags User
     * @name UserUpdateSlackOauthCallback
     * @summary Complete OAuth flow
     * @request GET:/api/v1/users/slack/callback
     * @secure
     */
    userUpdateSlackOauthCallback: (params?: RequestParams) => Promise<import("axios").AxiosResponse<any, any>>;
    /**
     * @description SNS event
     *
     * @tags Github
     * @name SnsUpdate
     * @summary Github app tenant webhook
     * @request POST:/api/v1/sns/{tenant}/{event}
     */
    snsUpdate: (tenant: string, event: string, params?: RequestParams) => Promise<import("axios").AxiosResponse<void, any>>;
    /**
     * @description List SNS integrations
     *
     * @tags SNS
     * @name SnsList
     * @summary List SNS integrations
     * @request GET:/api/v1/tenants/{tenant}/sns
     * @secure
     */
    snsList: (tenant: string, params?: RequestParams) => Promise<import("axios").AxiosResponse<ListSNSIntegrations, any>>;
    /**
     * @description Create SNS integration
     *
     * @tags SNS
     * @name SnsCreate
     * @summary Create SNS integration
     * @request POST:/api/v1/tenants/{tenant}/sns
     * @secure
     */
    snsCreate: (tenant: string, data: CreateSNSIntegrationRequest, params?: RequestParams) => Promise<import("axios").AxiosResponse<SNSIntegration, any>>;
    /**
     * @description Creates a new tenant alert email group
     *
     * @tags Tenant
     * @name AlertEmailGroupCreate
     * @summary Create tenant alert email group
     * @request POST:/api/v1/tenants/{tenant}/alerting-email-groups
     * @secure
     */
    alertEmailGroupCreate: (tenant: string, data: CreateTenantAlertEmailGroupRequest, params?: RequestParams) => Promise<import("axios").AxiosResponse<TenantAlertEmailGroup, any>>;
    /**
     * @description Gets a list of tenant alert email groups
     *
     * @tags Tenant
     * @name AlertEmailGroupList
     * @summary List tenant alert email groups
     * @request GET:/api/v1/tenants/{tenant}/alerting-email-groups
     * @secure
     */
    alertEmailGroupList: (tenant: string, params?: RequestParams) => Promise<import("axios").AxiosResponse<TenantAlertEmailGroupList, any>>;
    /**
     * @description Gets the resource policy for a tenant
     *
     * @tags Tenant
     * @name TenantResourcePolicyGet
     * @summary Create tenant alert email group
     * @request GET:/api/v1/tenants/{tenant}/resource-policy
     * @secure
     */
    tenantResourcePolicyGet: (tenant: string, params?: RequestParams) => Promise<import("axios").AxiosResponse<TenantResourcePolicy, any>>;
    /**
     * @description Updates a tenant alert email group
     *
     * @tags Tenant
     * @name AlertEmailGroupUpdate
     * @summary Update tenant alert email group
     * @request PATCH:/api/v1/alerting-email-groups/{alert-email-group}
     * @secure
     */
    alertEmailGroupUpdate: (alertEmailGroup: string, data: UpdateTenantAlertEmailGroupRequest, params?: RequestParams) => Promise<import("axios").AxiosResponse<TenantAlertEmailGroup, any>>;
    /**
     * @description Deletes a tenant alert email group
     *
     * @tags Tenant
     * @name AlertEmailGroupDelete
     * @summary Delete tenant alert email group
     * @request DELETE:/api/v1/alerting-email-groups/{alert-email-group}
     * @secure
     */
    alertEmailGroupDelete: (alertEmailGroup: string, params?: RequestParams) => Promise<import("axios").AxiosResponse<void, any>>;
    /**
     * @description Delete SNS integration
     *
     * @tags SNS
     * @name SnsDelete
     * @summary Delete SNS integration
     * @request DELETE:/api/v1/sns/{sns}
     * @secure
     */
    snsDelete: (sns: string, params?: RequestParams) => Promise<import("axios").AxiosResponse<void, any>>;
    /**
     * @description List Slack webhooks
     *
     * @tags Slack
     * @name SlackWebhookList
     * @summary List Slack integrations
     * @request GET:/api/v1/tenants/{tenant}/slack
     * @secure
     */
    slackWebhookList: (tenant: string, params?: RequestParams) => Promise<import("axios").AxiosResponse<ListSlackWebhooks, any>>;
    /**
     * @description Delete Slack webhook
     *
     * @tags Slack
     * @name SlackWebhookDelete
     * @summary Delete Slack webhook
     * @request DELETE:/api/v1/slack/{slack}
     * @secure
     */
    slackWebhookDelete: (slack: string, params?: RequestParams) => Promise<import("axios").AxiosResponse<void, any>>;
    /**
     * @description Gets the current user
     *
     * @tags User
     * @name UserGetCurrent
     * @summary Get current user
     * @request GET:/api/v1/users/current
     * @secure
     */
    userGetCurrent: (params?: RequestParams) => Promise<import("axios").AxiosResponse<User, any>>;
    /**
     * @description Update a user password.
     *
     * @tags User
     * @name UserUpdatePassword
     * @summary Change user password
     * @request POST:/api/v1/users/password
     * @secure
     */
    userUpdatePassword: (data: UserChangePasswordRequest, params?: RequestParams) => Promise<import("axios").AxiosResponse<User, any>>;
    /**
     * @description Registers a user.
     *
     * @tags User
     * @name UserCreate
     * @summary Register user
     * @request POST:/api/v1/users/register
     */
    userCreate: (data: UserRegisterRequest, params?: RequestParams) => Promise<import("axios").AxiosResponse<User, any>>;
    /**
     * @description Logs out a user.
     *
     * @tags User
     * @name UserUpdateLogout
     * @summary Logout user
     * @request POST:/api/v1/users/logout
     * @secure
     */
    userUpdateLogout: (params?: RequestParams) => Promise<import("axios").AxiosResponse<User, any>>;
    /**
     * @description Lists all tenant memberships for the current user
     *
     * @tags User
     * @name TenantMembershipsList
     * @summary List tenant memberships
     * @request GET:/api/v1/users/memberships
     * @secure
     */
    tenantMembershipsList: (params?: RequestParams) => Promise<import("axios").AxiosResponse<UserTenantMembershipsList, any>>;
    /**
     * @description Lists all tenant invites for the current user
     *
     * @tags Tenant
     * @name UserListTenantInvites
     * @summary List tenant invites
     * @request GET:/api/v1/users/invites
     * @secure
     */
    userListTenantInvites: (params?: RequestParams) => Promise<import("axios").AxiosResponse<TenantInviteList, any>>;
    /**
     * @description Accepts a tenant invite
     *
     * @tags Tenant
     * @name TenantInviteAccept
     * @summary Accept tenant invite
     * @request POST:/api/v1/users/invites/accept
     * @secure
     */
    tenantInviteAccept: (data: AcceptInviteRequest, params?: RequestParams) => Promise<import("axios").AxiosResponse<void, any>>;
    /**
     * @description Rejects a tenant invite
     *
     * @tags Tenant
     * @name TenantInviteReject
     * @summary Reject tenant invite
     * @request POST:/api/v1/users/invites/reject
     * @secure
     */
    tenantInviteReject: (data: RejectInviteRequest, params?: RequestParams) => Promise<import("axios").AxiosResponse<void, any>>;
    /**
     * @description Creates a new tenant
     *
     * @tags Tenant
     * @name TenantCreate
     * @summary Create tenant
     * @request POST:/api/v1/tenants
     * @secure
     */
    tenantCreate: (data: CreateTenantRequest, params?: RequestParams) => Promise<import("axios").AxiosResponse<Tenant, any>>;
    /**
     * @description Update an existing tenant
     *
     * @tags Tenant
     * @name TenantUpdate
     * @summary Update tenant
     * @request PATCH:/api/v1/tenants/{tenant}
     * @secure
     */
    tenantUpdate: (tenant: string, data: UpdateTenantRequest, params?: RequestParams) => Promise<import("axios").AxiosResponse<Tenant, any>>;
    /**
     * @description Gets the alerting settings for a tenant
     *
     * @tags Tenant
     * @name TenantAlertingSettingsGet
     * @summary Get tenant alerting settings
     * @request GET:/api/v1/tenants/{tenant}/alerting/settings
     * @secure
     */
    tenantAlertingSettingsGet: (tenant: string, params?: RequestParams) => Promise<import("axios").AxiosResponse<TenantAlertingSettings, any>>;
    /**
     * @description Creates a new tenant invite
     *
     * @tags Tenant
     * @name TenantInviteCreate
     * @summary Create tenant invite
     * @request POST:/api/v1/tenants/{tenant}/invites
     * @secure
     */
    tenantInviteCreate: (tenant: string, data: CreateTenantInviteRequest, params?: RequestParams) => Promise<import("axios").AxiosResponse<TenantInvite, any>>;
    /**
     * @description Gets a list of tenant invites
     *
     * @tags Tenant
     * @name TenantInviteList
     * @summary List tenant invites
     * @request GET:/api/v1/tenants/{tenant}/invites
     * @secure
     */
    tenantInviteList: (tenant: string, params?: RequestParams) => Promise<import("axios").AxiosResponse<TenantInviteList, any>>;
    /**
     * @description Updates a tenant invite
     *
     * @name TenantInviteUpdate
     * @summary Update invite
     * @request PATCH:/api/v1/tenants/{tenant}/invites/{tenant-invite}
     * @secure
     */
    tenantInviteUpdate: (tenant: string, tenantInvite: string, data: UpdateTenantInviteRequest, params?: RequestParams) => Promise<import("axios").AxiosResponse<TenantInvite, any>>;
    /**
     * @description Deletes a tenant invite
     *
     * @name TenantInviteDelete
     * @summary Delete invite
     * @request DELETE:/api/v1/tenants/{tenant}/invites/{tenant-invite}
     * @secure
     */
    tenantInviteDelete: (tenant: string, tenantInvite: string, params?: RequestParams) => Promise<import("axios").AxiosResponse<TenantInvite, any>>;
    /**
     * @description Create an API token for a tenant
     *
     * @tags API Token
     * @name ApiTokenCreate
     * @summary Create API Token
     * @request POST:/api/v1/tenants/{tenant}/api-tokens
     * @secure
     */
    apiTokenCreate: (tenant: string, data: CreateAPITokenRequest, params?: RequestParams) => Promise<import("axios").AxiosResponse<CreateAPITokenResponse, any>>;
    /**
     * @description List API tokens for a tenant
     *
     * @tags API Token
     * @name ApiTokenList
     * @summary List API Tokens
     * @request GET:/api/v1/tenants/{tenant}/api-tokens
     * @secure
     */
    apiTokenList: (tenant: string, params?: RequestParams) => Promise<import("axios").AxiosResponse<ListAPITokensResponse, any>>;
    /**
     * @description Revoke an API token for a tenant
     *
     * @tags API Token
     * @name ApiTokenUpdateRevoke
     * @summary Revoke API Token
     * @request POST:/api/v1/api-tokens/{api-token}
     * @secure
     */
    apiTokenUpdateRevoke: (apiToken: string, params?: RequestParams) => Promise<import("axios").AxiosResponse<void, any>>;
    /**
     * @description Get the queue metrics for the tenant
     *
     * @tags Workflow
     * @name TenantGetQueueMetrics
     * @summary Get workflow metrics
     * @request GET:/api/v1/tenants/{tenant}/queue-metrics
     * @secure
     */
    tenantGetQueueMetrics: (tenant: string, query?: {
        /** A list of workflow IDs to filter by */
        workflows?: WorkflowID[];
        /**
         * A list of metadata key value pairs to filter by
         * @example ["key1:value1","key2:value2"]
         */
        additionalMetadata?: string[];
    }, params?: RequestParams) => Promise<import("axios").AxiosResponse<TenantQueueMetrics, any>>;
    /**
     * @description Get the queue metrics for the tenant
     *
     * @tags Tenant
     * @name TenantGetStepRunQueueMetrics
     * @summary Get step run metrics
     * @request GET:/api/v1/tenants/{tenant}/step-run-queue-metrics
     * @secure
     */
    tenantGetStepRunQueueMetrics: (tenant: string, params?: RequestParams) => Promise<import("axios").AxiosResponse<TenantStepRunQueueMetrics, any>>;
    /**
     * @description Lists all events for a tenant.
     *
     * @tags Event
     * @name EventList
     * @summary List events
     * @request GET:/api/v1/tenants/{tenant}/events
     * @secure
     */
    eventList: (tenant: string, query?: {
        /**
         * The number to skip
         * @format int64
         */
        offset?: number;
        /**
         * The number to limit by
         * @format int64
         */
        limit?: number;
        /** A list of keys to filter by */
        keys?: EventKey[];
        /** A list of workflow IDs to filter by */
        workflows?: WorkflowID[];
        /** A list of workflow run statuses to filter by */
        statuses?: WorkflowRunStatusList;
        /** The search query to filter for */
        search?: EventSearch;
        /** What to order by */
        orderByField?: EventOrderByField;
        /** The order direction */
        orderByDirection?: EventOrderByDirection;
        /**
         * A list of metadata key value pairs to filter by
         * @example ["key1:value1","key2:value2"]
         */
        additionalMetadata?: string[];
        /** A list of event ids to filter by */
        eventIds?: string[];
    }, params?: RequestParams) => Promise<import("axios").AxiosResponse<EventList, any>>;
    /**
     * @description Creates a new event.
     *
     * @tags Event
     * @name EventCreate
     * @summary Create event
     * @request POST:/api/v1/tenants/{tenant}/events
     * @secure
     */
    eventCreate: (tenant: string, data: CreateEventRequest, params?: RequestParams) => Promise<import("axios").AxiosResponse<Event, any>>;
    /**
     * @description Bulk creates new events.
     *
     * @tags Event
     * @name EventCreateBulk
     * @summary Bulk Create events
     * @request POST:/api/v1/tenants/{tenant}/events/bulk
     * @secure
     */
    eventCreateBulk: (tenant: string, data: BulkCreateEventRequest, params?: RequestParams) => Promise<import("axios").AxiosResponse<BulkCreateEventResponse, any>>;
    /**
     * @description Replays a list of events.
     *
     * @tags Event
     * @name EventUpdateReplay
     * @summary Replay events
     * @request POST:/api/v1/tenants/{tenant}/events/replay
     * @secure
     */
    eventUpdateReplay: (tenant: string, data: ReplayEventRequest, params?: RequestParams) => Promise<import("axios").AxiosResponse<EventList, any>>;
    /**
     * @description Cancels all runs for a list of events.
     *
     * @tags Event
     * @name EventUpdateCancel
     * @summary Replay events
     * @request POST:/api/v1/tenants/{tenant}/events/cancel
     * @secure
     */
    eventUpdateCancel: (tenant: string, data: CancelEventRequest, params?: RequestParams) => Promise<import("axios").AxiosResponse<{
        workflowRunIds?: string[];
    }, any>>;
    /**
     * @description Lists all rate limits for a tenant.
     *
     * @tags Rate Limits
     * @name RateLimitList
     * @summary List rate limits
     * @request GET:/api/v1/tenants/{tenant}/rate-limits
     * @secure
     */
    rateLimitList: (tenant: string, query?: {
        /**
         * The number to skip
         * @format int64
         */
        offset?: number;
        /**
         * The number to limit by
         * @format int64
         */
        limit?: number;
        /** The search query to filter for */
        search?: string;
        /** What to order by */
        orderByField?: RateLimitOrderByField;
        /** The order direction */
        orderByDirection?: RateLimitOrderByDirection;
    }, params?: RequestParams) => Promise<import("axios").AxiosResponse<RateLimitList, any>>;
    /**
     * @description Gets a list of tenant members
     *
     * @tags Tenant
     * @name TenantMemberList
     * @summary List tenant members
     * @request GET:/api/v1/tenants/{tenant}/members
     * @secure
     */
    tenantMemberList: (tenant: string, params?: RequestParams) => Promise<import("axios").AxiosResponse<TenantMemberList, any>>;
    /**
     * @description Delete a member from a tenant
     *
     * @tags Tenant
     * @name TenantMemberDelete
     * @summary Delete a tenant member
     * @request DELETE:/api/v1/tenants/{tenant}/members/{member}
     * @secure
     */
    tenantMemberDelete: (tenant: string, member: string, params?: RequestParams) => Promise<import("axios").AxiosResponse<TenantMember, any>>;
    /**
     * @description Get an event.
     *
     * @tags Event
     * @name EventGet
     * @summary Get event data
     * @request GET:/api/v1/events/{event}
     * @secure
     */
    eventGet: (event: string, params?: RequestParams) => Promise<import("axios").AxiosResponse<Event, any>>;
    /**
     * @description Get the data for an event.
     *
     * @tags Event
     * @name EventDataGet
     * @summary Get event data
     * @request GET:/api/v1/events/{event}/data
     * @secure
     */
    eventDataGet: (event: string, params?: RequestParams) => Promise<import("axios").AxiosResponse<EventData, any>>;
    /**
     * @description Lists all event keys for a tenant.
     *
     * @tags Event
     * @name EventKeyList
     * @summary List event keys
     * @request GET:/api/v1/tenants/{tenant}/events/keys
     * @secure
     */
    eventKeyList: (tenant: string, params?: RequestParams) => Promise<import("axios").AxiosResponse<EventKeyList, any>>;
    /**
     * @description Get all workflows for a tenant
     *
     * @tags Workflow
     * @name WorkflowList
     * @summary Get workflows
     * @request GET:/api/v1/tenants/{tenant}/workflows
     * @secure
     */
    workflowList: (tenant: string, params?: RequestParams) => Promise<import("axios").AxiosResponse<WorkflowList, any>>;
    /**
     * @description Cancel a batch of workflow runs
     *
     * @tags Workflow Run
     * @name WorkflowRunCancel
     * @summary Cancel workflow runs
     * @request POST:/api/v1/tenants/{tenant}/workflows/cancel
     * @secure
     */
    workflowRunCancel: (tenant: string, data: WorkflowRunsCancelRequest, params?: RequestParams) => Promise<import("axios").AxiosResponse<{
        workflowRunIds?: string[];
    }, any>>;
    /**
     * @description Get a workflow for a tenant
     *
     * @tags Workflow
     * @name WorkflowGet
     * @summary Get workflow
     * @request GET:/api/v1/workflows/{workflow}
     * @secure
     */
    workflowGet: (workflow: string, params?: RequestParams) => Promise<import("axios").AxiosResponse<Workflow, any>>;
    /**
     * @description Delete a workflow for a tenant
     *
     * @tags Workflow
     * @name WorkflowDelete
     * @summary Delete workflow
     * @request DELETE:/api/v1/workflows/{workflow}
     * @secure
     */
    workflowDelete: (workflow: string, params?: RequestParams) => Promise<import("axios").AxiosResponse<void, any>>;
    /**
     * @description Update a workflow for a tenant
     *
     * @tags Workflow
     * @name WorkflowUpdate
     * @summary Update workflow
     * @request PATCH:/api/v1/workflows/{workflow}
     * @secure
     */
    workflowUpdate: (workflow: string, data: WorkflowUpdateRequest, params?: RequestParams) => Promise<import("axios").AxiosResponse<Workflow, any>>;
    /**
     * @description Get a workflow version for a tenant
     *
     * @tags Workflow
     * @name WorkflowVersionGet
     * @summary Get workflow version
     * @request GET:/api/v1/workflows/{workflow}/versions
     * @secure
     */
    workflowVersionGet: (workflow: string, query?: {
        /**
         * The workflow version. If not supplied, the latest version is fetched.
         * @format uuid
         * @minLength 36
         * @maxLength 36
         */
        version?: string;
    }, params?: RequestParams) => Promise<import("axios").AxiosResponse<WorkflowVersion, any>>;
    /**
     * @description Trigger a new workflow run for a tenant
     *
     * @tags Workflow Run
     * @name WorkflowRunCreate
     * @summary Trigger workflow run
     * @request POST:/api/v1/workflows/{workflow}/trigger
     * @secure
     */
    workflowRunCreate: (workflow: string, data: TriggerWorkflowRunRequest, query?: {
        /**
         * The workflow version. If not supplied, the latest version is fetched.
         * @format uuid
         * @minLength 36
         * @maxLength 36
         */
        version?: string;
    }, params?: RequestParams) => Promise<import("axios").AxiosResponse<WorkflowRun, any>>;
    /**
     * @description Get the metrics for a workflow version
     *
     * @tags Workflow
     * @name WorkflowGetMetrics
     * @summary Get workflow metrics
     * @request GET:/api/v1/workflows/{workflow}/metrics
     * @secure
     */
    workflowGetMetrics: (workflow: string, query?: {
        /** A status of workflow run statuses to filter by */
        status?: WorkflowRunStatus;
        /** A group key to filter metrics by */
        groupKey?: string;
    }, params?: RequestParams) => Promise<import("axios").AxiosResponse<WorkflowMetrics, any>>;
    /**
     * @description Lists log lines for a step run.
     *
     * @tags Log
     * @name LogLineList
     * @summary List log lines
     * @request GET:/api/v1/step-runs/{step-run}/logs
     * @secure
     */
    logLineList: (stepRun: string, query?: {
        /**
         * The number to skip
         * @format int64
         */
        offset?: number;
        /**
         * The number to limit by
         * @format int64
         */
        limit?: number;
        /** A list of levels to filter by */
        levels?: LogLineLevelField;
        /** The search query to filter for */
        search?: LogLineSearch;
        /** What to order by */
        orderByField?: LogLineOrderByField;
        /** The order direction */
        orderByDirection?: LogLineOrderByDirection;
    }, params?: RequestParams) => Promise<import("axios").AxiosResponse<LogLineList, any>>;
    /**
     * @description List events for a step run
     *
     * @tags Step Run
     * @name StepRunListEvents
     * @summary List events for step run
     * @request GET:/api/v1/step-runs/{step-run}/events
     * @secure
     */
    stepRunListEvents: (stepRun: string, query?: {
        /**
         * The number to skip
         * @format int64
         */
        offset?: number;
        /**
         * The number to limit by
         * @format int64
         */
        limit?: number;
    }, params?: RequestParams) => Promise<import("axios").AxiosResponse<StepRunEventList, any>>;
    /**
     * @description List events for all step runs for a workflow run
     *
     * @tags Step Run
     * @name WorkflowRunListStepRunEvents
     * @summary List events for all step runs for a workflow run
     * @request GET:/api/v1/tenants/{tenant}/workflow-runs/{workflow-run}/step-run-events
     * @secure
     */
    workflowRunListStepRunEvents: (tenant: string, workflowRun: string, query?: {
        /**
         * Last ID of the last event
         * @format int32
         */
        lastId?: number;
    }, params?: RequestParams) => Promise<import("axios").AxiosResponse<StepRunEventList, any>>;
    /**
     * @description List archives for a step run
     *
     * @tags Step Run
     * @name StepRunListArchives
     * @summary List archives for step run
     * @request GET:/api/v1/step-runs/{step-run}/archives
     * @secure
     */
    stepRunListArchives: (stepRun: string, query?: {
        /**
         * The number to skip
         * @format int64
         */
        offset?: number;
        /**
         * The number to limit by
         * @format int64
         */
        limit?: number;
    }, params?: RequestParams) => Promise<import("axios").AxiosResponse<StepRunArchiveList, any>>;
    /**
     * @description Get a count of the workers available for workflow
     *
     * @tags Workflow
     * @name WorkflowGetWorkersCount
     * @summary Get workflow worker count
     * @request GET:/api/v1/tenants/{tenant}/workflows/{workflow}/worker-count
     * @secure
     */
    workflowGetWorkersCount: (tenant: string, workflow: string, params?: RequestParams) => Promise<import("axios").AxiosResponse<WorkflowWorkersCount, any>>;
    /**
     * @description Get all workflow runs for a tenant
     *
     * @tags Workflow
     * @name WorkflowRunList
     * @summary Get workflow runs
     * @request GET:/api/v1/tenants/{tenant}/workflows/runs
     * @secure
     */
    workflowRunList: (tenant: string, query?: {
        /**
         * The number to skip
         * @format int64
         */
        offset?: number;
        /**
         * The number to limit by
         * @format int64
         */
        limit?: number;
        /**
         * The event id to get runs for.
         * @format uuid
         * @minLength 36
         * @maxLength 36
         */
        eventId?: string;
        /**
         * The workflow id to get runs for.
         * @format uuid
         * @minLength 36
         * @maxLength 36
         */
        workflowId?: string;
        /**
         * The parent workflow run id
         * @format uuid
         * @minLength 36
         * @maxLength 36
         */
        parentWorkflowRunId?: string;
        /**
         * The parent step run id
         * @format uuid
         * @minLength 36
         * @maxLength 36
         */
        parentStepRunId?: string;
        /** A list of workflow run statuses to filter by */
        statuses?: WorkflowRunStatusList;
        /** A list of workflow kinds to filter by */
        kinds?: WorkflowKindList;
        /**
         * A list of metadata key value pairs to filter by
         * @example ["key1:value1","key2:value2"]
         */
        additionalMetadata?: string[];
        /**
         * The time after the workflow run was created
         * @format date-time
         * @example "2021-01-01T00:00:00Z"
         */
        createdAfter?: string;
        /**
         * The time before the workflow run was created
         * @format date-time
         * @example "2021-01-01T00:00:00Z"
         */
        createdBefore?: string;
        /**
         * The time after the workflow run was finished
         * @format date-time
         * @example "2021-01-01T00:00:00Z"
         */
        finishedAfter?: string;
        /**
         * The time before the workflow run was finished
         * @format date-time
         * @example "2021-01-01T00:00:00Z"
         */
        finishedBefore?: string;
        /** The order by field */
        orderByField?: WorkflowRunOrderByField;
        /** The order by direction */
        orderByDirection?: WorkflowRunOrderByDirection;
    }, params?: RequestParams) => Promise<import("axios").AxiosResponse<WorkflowRunList, any>>;
    /**
     * @description Replays a list of workflow runs.
     *
     * @tags Workflow Run
     * @name WorkflowRunUpdateReplay
     * @summary Replay workflow runs
     * @request POST:/api/v1/tenants/{tenant}/workflow-runs/replay
     * @secure
     */
    workflowRunUpdateReplay: (tenant: string, data: ReplayWorkflowRunsRequest, params?: RequestParams) => Promise<import("axios").AxiosResponse<ReplayWorkflowRunsResponse, any>>;
    /**
     * @description Get a summary of  workflow run metrics for a tenant
     *
     * @tags Workflow
     * @name WorkflowRunGetMetrics
     * @summary Get workflow runs
     * @request GET:/api/v1/tenants/{tenant}/workflows/runs/metrics
     * @secure
     */
    workflowRunGetMetrics: (tenant: string, query?: {
        /**
         * The event id to get runs for.
         * @format uuid
         * @minLength 36
         * @maxLength 36
         */
        eventId?: string;
        /**
         * The workflow id to get runs for.
         * @format uuid
         * @minLength 36
         * @maxLength 36
         */
        workflowId?: string;
        /**
         * The parent workflow run id
         * @format uuid
         * @minLength 36
         * @maxLength 36
         */
        parentWorkflowRunId?: string;
        /**
         * The parent step run id
         * @format uuid
         * @minLength 36
         * @maxLength 36
         */
        parentStepRunId?: string;
        /**
         * A list of metadata key value pairs to filter by
         * @example ["key1:value1","key2:value2"]
         */
        additionalMetadata?: string[];
        /**
         * The time after the workflow run was created
         * @format date-time
         * @example "2021-01-01T00:00:00Z"
         */
        createdAfter?: string;
        /**
         * The time before the workflow run was created
         * @format date-time
         * @example "2021-01-01T00:00:00Z"
         */
        createdBefore?: string;
    }, params?: RequestParams) => Promise<import("axios").AxiosResponse<WorkflowRunsMetrics, any>>;
    /**
     * @description Get a workflow run for a tenant
     *
     * @tags Workflow
     * @name WorkflowRunGet
     * @summary Get workflow run
     * @request GET:/api/v1/tenants/{tenant}/workflow-runs/{workflow-run}
     * @secure
     */
    workflowRunGet: (tenant: string, workflowRun: string, params?: RequestParams) => Promise<import("axios").AxiosResponse<WorkflowRun, any>>;
    /**
     * @description Get a workflow run for a tenant
     *
     * @tags Workflow
     * @name WorkflowRunGetShape
     * @summary Get workflow run
     * @request GET:/api/v1/tenants/{tenant}/workflow-runs/{workflow-run}/shape
     * @secure
     */
    workflowRunGetShape: (tenant: string, workflowRun: string, params?: RequestParams) => Promise<import("axios").AxiosResponse<WorkflowRunShape, any>>;
    /**
     * @description Get a step run by id
     *
     * @tags Step Run
     * @name StepRunGet
     * @summary Get step run
     * @request GET:/api/v1/tenants/{tenant}/step-runs/{step-run}
     * @secure
     */
    stepRunGet: (tenant: string, stepRun: string, params?: RequestParams) => Promise<import("axios").AxiosResponse<StepRun, any>>;
    /**
     * @description Reruns a step run
     *
     * @tags Step Run
     * @name StepRunUpdateRerun
     * @summary Rerun step run
     * @request POST:/api/v1/tenants/{tenant}/step-runs/{step-run}/rerun
     * @secure
     */
    stepRunUpdateRerun: (tenant: string, stepRun: string, data: RerunStepRunRequest, params?: RequestParams) => Promise<import("axios").AxiosResponse<StepRun, any>>;
    /**
     * @description Attempts to cancel a step run
     *
     * @tags Step Run
     * @name StepRunUpdateCancel
     * @summary Attempts to cancel a step run
     * @request POST:/api/v1/tenants/{tenant}/step-runs/{step-run}/cancel
     * @secure
     */
    stepRunUpdateCancel: (tenant: string, stepRun: string, params?: RequestParams) => Promise<import("axios").AxiosResponse<StepRun, any>>;
    /**
     * @description Get the schema for a step run
     *
     * @tags Step Run
     * @name StepRunGetSchema
     * @summary Get step run schema
     * @request GET:/api/v1/tenants/{tenant}/step-runs/{step-run}/schema
     * @secure
     */
    stepRunGetSchema: (tenant: string, stepRun: string, params?: RequestParams) => Promise<import("axios").AxiosResponse<object, any>>;
    /**
     * @description Get all workers for a tenant
     *
     * @tags Worker
     * @name WorkerList
     * @summary Get workers
     * @request GET:/api/v1/tenants/{tenant}/worker
     * @secure
     */
    workerList: (tenant: string, params?: RequestParams) => Promise<import("axios").AxiosResponse<WorkerList, any>>;
    /**
     * @description Update a worker
     *
     * @tags Worker
     * @name WorkerUpdate
     * @summary Update worker
     * @request PATCH:/api/v1/workers/{worker}
     * @secure
     */
    workerUpdate: (worker: string, data: UpdateWorkerRequest, params?: RequestParams) => Promise<import("axios").AxiosResponse<Worker, any>>;
    /**
     * @description Get a worker
     *
     * @tags Worker
     * @name WorkerGet
     * @summary Get worker
     * @request GET:/api/v1/workers/{worker}
     * @secure
     */
    workerGet: (worker: string, params?: RequestParams) => Promise<import("axios").AxiosResponse<Worker, any>>;
    /**
     * @description Lists all webhooks
     *
     * @name WebhookList
     * @summary List webhooks
     * @request GET:/api/v1/tenants/{tenant}/webhook-workers
     * @secure
     */
    webhookList: (tenant: string, params?: RequestParams) => Promise<import("axios").AxiosResponse<WebhookWorkerListResponse, any>>;
    /**
     * @description Creates a webhook
     *
     * @name WebhookCreate
     * @summary Create a webhook
     * @request POST:/api/v1/tenants/{tenant}/webhook-workers
     * @secure
     */
    webhookCreate: (tenant: string, data: WebhookWorkerCreateRequest, params?: RequestParams) => Promise<import("axios").AxiosResponse<WebhookWorkerCreated, any>>;
    /**
     * @description Deletes a webhook
     *
     * @name WebhookDelete
     * @summary Delete a webhook
     * @request DELETE:/api/v1/webhook-workers/{webhook}
     * @secure
     */
    webhookDelete: (webhook: string, params?: RequestParams) => Promise<import("axios").AxiosResponse<void, any>>;
    /**
     * @description Lists all requests for a webhook
     *
     * @name WebhookRequestsList
     * @summary List webhook requests
     * @request GET:/api/v1/webhook-workers/{webhook}/requests
     * @secure
     */
    webhookRequestsList: (webhook: string, params?: RequestParams) => Promise<import("axios").AxiosResponse<WebhookWorkerRequestListResponse, any>>;
    /**
     * @description Get the input for a workflow run.
     *
     * @tags Workflow Run
     * @name WorkflowRunGetInput
     * @summary Get workflow run input
     * @request GET:/api/v1/tenants/{tenant}/workflow-runs/{workflow-run}/input
     * @secure
     */
    workflowRunGetInput: (tenant: string, workflowRun: string, params?: RequestParams) => Promise<import("axios").AxiosResponse<Record<string, any>, any>>;
}
