import { BinaryReader, BinaryWriter } from '@bufbuild/protobuf/wire';
import { type CallContext, type CallOptions } from 'nice-grpc-common';
export declare const protobufPackage = "";
export declare enum ActionType {
    START_STEP_RUN = 0,
    CANCEL_STEP_RUN = 1,
    START_GET_GROUP_KEY = 2,
    UNRECOGNIZED = -1
}
export declare function actionTypeFromJSON(object: any): ActionType;
export declare function actionTypeToJSON(object: ActionType): string;
export declare enum GroupKeyActionEventType {
    GROUP_KEY_EVENT_TYPE_UNKNOWN = 0,
    GROUP_KEY_EVENT_TYPE_STARTED = 1,
    GROUP_KEY_EVENT_TYPE_COMPLETED = 2,
    GROUP_KEY_EVENT_TYPE_FAILED = 3,
    UNRECOGNIZED = -1
}
export declare function groupKeyActionEventTypeFromJSON(object: any): GroupKeyActionEventType;
export declare function groupKeyActionEventTypeToJSON(object: GroupKeyActionEventType): string;
export declare enum StepActionEventType {
    STEP_EVENT_TYPE_UNKNOWN = 0,
    STEP_EVENT_TYPE_STARTED = 1,
    STEP_EVENT_TYPE_COMPLETED = 2,
    STEP_EVENT_TYPE_FAILED = 3,
    STEP_EVENT_TYPE_ACKNOWLEDGED = 4,
    UNRECOGNIZED = -1
}
export declare function stepActionEventTypeFromJSON(object: any): StepActionEventType;
export declare function stepActionEventTypeToJSON(object: StepActionEventType): string;
export declare enum ResourceType {
    RESOURCE_TYPE_UNKNOWN = 0,
    RESOURCE_TYPE_STEP_RUN = 1,
    RESOURCE_TYPE_WORKFLOW_RUN = 2,
    UNRECOGNIZED = -1
}
export declare function resourceTypeFromJSON(object: any): ResourceType;
export declare function resourceTypeToJSON(object: ResourceType): string;
export declare enum ResourceEventType {
    RESOURCE_EVENT_TYPE_UNKNOWN = 0,
    RESOURCE_EVENT_TYPE_STARTED = 1,
    RESOURCE_EVENT_TYPE_COMPLETED = 2,
    RESOURCE_EVENT_TYPE_FAILED = 3,
    RESOURCE_EVENT_TYPE_CANCELLED = 4,
    RESOURCE_EVENT_TYPE_TIMED_OUT = 5,
    RESOURCE_EVENT_TYPE_STREAM = 6,
    UNRECOGNIZED = -1
}
export declare function resourceEventTypeFromJSON(object: any): ResourceEventType;
export declare function resourceEventTypeToJSON(object: ResourceEventType): string;
export declare enum WorkflowRunEventType {
    WORKFLOW_RUN_EVENT_TYPE_FINISHED = 0,
    UNRECOGNIZED = -1
}
export declare function workflowRunEventTypeFromJSON(object: any): WorkflowRunEventType;
export declare function workflowRunEventTypeToJSON(object: WorkflowRunEventType): string;
export interface WorkerLabels {
    /** value of the label */
    strValue?: string | undefined;
    intValue?: number | undefined;
}
export interface WorkerRegisterRequest {
    /** the name of the worker */
    workerName: string;
    /** a list of actions that this worker can run */
    actions: string[];
    /** (optional) the services for this worker */
    services: string[];
    /** (optional) the max number of runs this worker can handle */
    maxRuns?: number | undefined;
    /** (optional) worker labels (i.e. state or other metadata) */
    labels: {
        [key: string]: WorkerLabels;
    };
    /** (optional) webhookId is the id of the webhook that the worker is associated with (if any) */
    webhookId?: string | undefined;
}
export interface WorkerRegisterRequest_LabelsEntry {
    key: string;
    value: WorkerLabels | undefined;
}
export interface WorkerRegisterResponse {
    /** the tenant id */
    tenantId: string;
    /** the id of the worker */
    workerId: string;
    /** the name of the worker */
    workerName: string;
}
export interface UpsertWorkerLabelsRequest {
    /** the name of the worker */
    workerId: string;
    /** (optional) the worker labels */
    labels: {
        [key: string]: WorkerLabels;
    };
}
export interface UpsertWorkerLabelsRequest_LabelsEntry {
    key: string;
    value: WorkerLabels | undefined;
}
export interface UpsertWorkerLabelsResponse {
    /** the tenant id */
    tenantId: string;
    /** the id of the worker */
    workerId: string;
}
export interface AssignedAction {
    /** the tenant id */
    tenantId: string;
    /** the workflow run id (optional) */
    workflowRunId: string;
    /** the get group key run id (optional) */
    getGroupKeyRunId: string;
    /** the job id */
    jobId: string;
    /** the job name */
    jobName: string;
    /** the job run id */
    jobRunId: string;
    /** the step id */
    stepId: string;
    /** the step run id */
    stepRunId: string;
    /** the action id */
    actionId: string;
    /** the action type */
    actionType: ActionType;
    /** the action payload */
    actionPayload: string;
    /** the step name */
    stepName: string;
    /** the count number of the retry attempt */
    retryCount: number;
    /** (optional) additional metadata set on the workflow */
    additionalMetadata?: string | undefined;
    /** (optional) the child workflow index (if this is a child workflow) */
    childWorkflowIndex?: number | undefined;
    /** (optional) the child workflow key (if this is a child workflow) */
    childWorkflowKey?: string | undefined;
    /** (optional) the parent workflow run id (if this is a child workflow) */
    parentWorkflowRunId?: string | undefined;
}
export interface WorkerListenRequest {
    /** the id of the worker */
    workerId: string;
}
export interface WorkerUnsubscribeRequest {
    /** the id of the worker */
    workerId: string;
}
export interface WorkerUnsubscribeResponse {
    /** the tenant id to unsubscribe from */
    tenantId: string;
    /** the id of the worker */
    workerId: string;
}
export interface GroupKeyActionEvent {
    /** the id of the worker */
    workerId: string;
    /** the id of the job */
    workflowRunId: string;
    getGroupKeyRunId: string;
    /** the action id */
    actionId: string;
    eventTimestamp: Date | undefined;
    /** the step event type */
    eventType: GroupKeyActionEventType;
    /** the event payload */
    eventPayload: string;
}
export interface StepActionEvent {
    /** the id of the worker */
    workerId: string;
    /** the id of the job */
    jobId: string;
    /** the job run id */
    jobRunId: string;
    /** the id of the step */
    stepId: string;
    /** the step run id */
    stepRunId: string;
    /** the action id */
    actionId: string;
    eventTimestamp: Date | undefined;
    /** the step event type */
    eventType: StepActionEventType;
    /** the event payload */
    eventPayload: string;
}
export interface ActionEventResponse {
    /** the tenant id */
    tenantId: string;
    /** the id of the worker */
    workerId: string;
}
export interface SubscribeToWorkflowEventsRequest {
    /** the id of the workflow run */
    workflowRunId?: string | undefined;
    /** the key of the additional meta field to subscribe to */
    additionalMetaKey?: string | undefined;
    /** the value of the additional meta field to subscribe to */
    additionalMetaValue?: string | undefined;
}
export interface SubscribeToWorkflowRunsRequest {
    /** the id of the workflow run */
    workflowRunId: string;
}
export interface WorkflowEvent {
    /** the id of the workflow run */
    workflowRunId: string;
    resourceType: ResourceType;
    eventType: ResourceEventType;
    resourceId: string;
    eventTimestamp: Date | undefined;
    /** the event payload */
    eventPayload: string;
    /**
     * whether this is the last event for the workflow run - server
     * will hang up the connection but clients might want to case
     */
    hangup: boolean;
    /** (optional) the max number of retries this step can handle */
    stepRetries?: number | undefined;
    /** (optional) the retry count of this step */
    retryCount?: number | undefined;
}
export interface WorkflowRunEvent {
    /** the id of the workflow run */
    workflowRunId: string;
    eventType: WorkflowRunEventType;
    eventTimestamp: Date | undefined;
    results: StepRunResult[];
}
export interface StepRunResult {
    stepRunId: string;
    stepReadableId: string;
    jobRunId: string;
    error?: string | undefined;
    output?: string | undefined;
}
export interface OverridesData {
    /** the step run id */
    stepRunId: string;
    /** the path of the data to set */
    path: string;
    /** the value to set */
    value: string;
    /** the filename of the caller */
    callerFilename: string;
}
export interface OverridesDataResponse {
}
export interface HeartbeatRequest {
    /** the id of the worker */
    workerId: string;
    /** heartbeatAt is the time the worker sent the heartbeat */
    heartbeatAt: Date | undefined;
}
export interface HeartbeatResponse {
}
export interface RefreshTimeoutRequest {
    /** the id of the step run to release */
    stepRunId: string;
    incrementTimeoutBy: string;
}
export interface RefreshTimeoutResponse {
    timeoutAt: Date | undefined;
}
export interface ReleaseSlotRequest {
    /** the id of the step run to release */
    stepRunId: string;
}
export interface ReleaseSlotResponse {
}
export declare const WorkerLabels: MessageFns<WorkerLabels>;
export declare const WorkerRegisterRequest: MessageFns<WorkerRegisterRequest>;
export declare const WorkerRegisterRequest_LabelsEntry: MessageFns<WorkerRegisterRequest_LabelsEntry>;
export declare const WorkerRegisterResponse: MessageFns<WorkerRegisterResponse>;
export declare const UpsertWorkerLabelsRequest: MessageFns<UpsertWorkerLabelsRequest>;
export declare const UpsertWorkerLabelsRequest_LabelsEntry: MessageFns<UpsertWorkerLabelsRequest_LabelsEntry>;
export declare const UpsertWorkerLabelsResponse: MessageFns<UpsertWorkerLabelsResponse>;
export declare const AssignedAction: MessageFns<AssignedAction>;
export declare const WorkerListenRequest: MessageFns<WorkerListenRequest>;
export declare const WorkerUnsubscribeRequest: MessageFns<WorkerUnsubscribeRequest>;
export declare const WorkerUnsubscribeResponse: MessageFns<WorkerUnsubscribeResponse>;
export declare const GroupKeyActionEvent: MessageFns<GroupKeyActionEvent>;
export declare const StepActionEvent: MessageFns<StepActionEvent>;
export declare const ActionEventResponse: MessageFns<ActionEventResponse>;
export declare const SubscribeToWorkflowEventsRequest: MessageFns<SubscribeToWorkflowEventsRequest>;
export declare const SubscribeToWorkflowRunsRequest: MessageFns<SubscribeToWorkflowRunsRequest>;
export declare const WorkflowEvent: MessageFns<WorkflowEvent>;
export declare const WorkflowRunEvent: MessageFns<WorkflowRunEvent>;
export declare const StepRunResult: MessageFns<StepRunResult>;
export declare const OverridesData: MessageFns<OverridesData>;
export declare const OverridesDataResponse: MessageFns<OverridesDataResponse>;
export declare const HeartbeatRequest: MessageFns<HeartbeatRequest>;
export declare const HeartbeatResponse: MessageFns<HeartbeatResponse>;
export declare const RefreshTimeoutRequest: MessageFns<RefreshTimeoutRequest>;
export declare const RefreshTimeoutResponse: MessageFns<RefreshTimeoutResponse>;
export declare const ReleaseSlotRequest: MessageFns<ReleaseSlotRequest>;
export declare const ReleaseSlotResponse: MessageFns<ReleaseSlotResponse>;
export type DispatcherDefinition = typeof DispatcherDefinition;
export declare const DispatcherDefinition: {
    readonly name: "Dispatcher";
    readonly fullName: "Dispatcher";
    readonly methods: {
        readonly register: {
            readonly name: "Register";
            readonly requestType: MessageFns<WorkerRegisterRequest>;
            readonly requestStream: false;
            readonly responseType: MessageFns<WorkerRegisterResponse>;
            readonly responseStream: false;
            readonly options: {};
        };
        readonly listen: {
            readonly name: "Listen";
            readonly requestType: MessageFns<WorkerListenRequest>;
            readonly requestStream: false;
            readonly responseType: MessageFns<AssignedAction>;
            readonly responseStream: true;
            readonly options: {};
        };
        /**
         * ListenV2 is like listen, but implementation does not include heartbeats. This should only used by SDKs
         * against engine version v0.18.1+
         */
        readonly listenV2: {
            readonly name: "ListenV2";
            readonly requestType: MessageFns<WorkerListenRequest>;
            readonly requestStream: false;
            readonly responseType: MessageFns<AssignedAction>;
            readonly responseStream: true;
            readonly options: {};
        };
        /** Heartbeat is a method for workers to send heartbeats to the dispatcher */
        readonly heartbeat: {
            readonly name: "Heartbeat";
            readonly requestType: MessageFns<HeartbeatRequest>;
            readonly requestStream: false;
            readonly responseType: MessageFns<HeartbeatResponse>;
            readonly responseStream: false;
            readonly options: {};
        };
        readonly subscribeToWorkflowEvents: {
            readonly name: "SubscribeToWorkflowEvents";
            readonly requestType: MessageFns<SubscribeToWorkflowEventsRequest>;
            readonly requestStream: false;
            readonly responseType: MessageFns<WorkflowEvent>;
            readonly responseStream: true;
            readonly options: {};
        };
        readonly subscribeToWorkflowRuns: {
            readonly name: "SubscribeToWorkflowRuns";
            readonly requestType: MessageFns<SubscribeToWorkflowRunsRequest>;
            readonly requestStream: true;
            readonly responseType: MessageFns<WorkflowRunEvent>;
            readonly responseStream: true;
            readonly options: {};
        };
        readonly sendStepActionEvent: {
            readonly name: "SendStepActionEvent";
            readonly requestType: MessageFns<StepActionEvent>;
            readonly requestStream: false;
            readonly responseType: MessageFns<ActionEventResponse>;
            readonly responseStream: false;
            readonly options: {};
        };
        readonly sendGroupKeyActionEvent: {
            readonly name: "SendGroupKeyActionEvent";
            readonly requestType: MessageFns<GroupKeyActionEvent>;
            readonly requestStream: false;
            readonly responseType: MessageFns<ActionEventResponse>;
            readonly responseStream: false;
            readonly options: {};
        };
        readonly putOverridesData: {
            readonly name: "PutOverridesData";
            readonly requestType: MessageFns<OverridesData>;
            readonly requestStream: false;
            readonly responseType: MessageFns<OverridesDataResponse>;
            readonly responseStream: false;
            readonly options: {};
        };
        readonly unsubscribe: {
            readonly name: "Unsubscribe";
            readonly requestType: MessageFns<WorkerUnsubscribeRequest>;
            readonly requestStream: false;
            readonly responseType: MessageFns<WorkerUnsubscribeResponse>;
            readonly responseStream: false;
            readonly options: {};
        };
        readonly refreshTimeout: {
            readonly name: "RefreshTimeout";
            readonly requestType: MessageFns<RefreshTimeoutRequest>;
            readonly requestStream: false;
            readonly responseType: MessageFns<RefreshTimeoutResponse>;
            readonly responseStream: false;
            readonly options: {};
        };
        readonly releaseSlot: {
            readonly name: "ReleaseSlot";
            readonly requestType: MessageFns<ReleaseSlotRequest>;
            readonly requestStream: false;
            readonly responseType: MessageFns<ReleaseSlotResponse>;
            readonly responseStream: false;
            readonly options: {};
        };
        readonly upsertWorkerLabels: {
            readonly name: "UpsertWorkerLabels";
            readonly requestType: MessageFns<UpsertWorkerLabelsRequest>;
            readonly requestStream: false;
            readonly responseType: MessageFns<UpsertWorkerLabelsResponse>;
            readonly responseStream: false;
            readonly options: {};
        };
    };
};
export interface DispatcherServiceImplementation<CallContextExt = {}> {
    register(request: WorkerRegisterRequest, context: CallContext & CallContextExt): Promise<DeepPartial<WorkerRegisterResponse>>;
    listen(request: WorkerListenRequest, context: CallContext & CallContextExt): ServerStreamingMethodResult<DeepPartial<AssignedAction>>;
    /**
     * ListenV2 is like listen, but implementation does not include heartbeats. This should only used by SDKs
     * against engine version v0.18.1+
     */
    listenV2(request: WorkerListenRequest, context: CallContext & CallContextExt): ServerStreamingMethodResult<DeepPartial<AssignedAction>>;
    /** Heartbeat is a method for workers to send heartbeats to the dispatcher */
    heartbeat(request: HeartbeatRequest, context: CallContext & CallContextExt): Promise<DeepPartial<HeartbeatResponse>>;
    subscribeToWorkflowEvents(request: SubscribeToWorkflowEventsRequest, context: CallContext & CallContextExt): ServerStreamingMethodResult<DeepPartial<WorkflowEvent>>;
    subscribeToWorkflowRuns(request: AsyncIterable<SubscribeToWorkflowRunsRequest>, context: CallContext & CallContextExt): ServerStreamingMethodResult<DeepPartial<WorkflowRunEvent>>;
    sendStepActionEvent(request: StepActionEvent, context: CallContext & CallContextExt): Promise<DeepPartial<ActionEventResponse>>;
    sendGroupKeyActionEvent(request: GroupKeyActionEvent, context: CallContext & CallContextExt): Promise<DeepPartial<ActionEventResponse>>;
    putOverridesData(request: OverridesData, context: CallContext & CallContextExt): Promise<DeepPartial<OverridesDataResponse>>;
    unsubscribe(request: WorkerUnsubscribeRequest, context: CallContext & CallContextExt): Promise<DeepPartial<WorkerUnsubscribeResponse>>;
    refreshTimeout(request: RefreshTimeoutRequest, context: CallContext & CallContextExt): Promise<DeepPartial<RefreshTimeoutResponse>>;
    releaseSlot(request: ReleaseSlotRequest, context: CallContext & CallContextExt): Promise<DeepPartial<ReleaseSlotResponse>>;
    upsertWorkerLabels(request: UpsertWorkerLabelsRequest, context: CallContext & CallContextExt): Promise<DeepPartial<UpsertWorkerLabelsResponse>>;
}
export interface DispatcherClient<CallOptionsExt = {}> {
    register(request: DeepPartial<WorkerRegisterRequest>, options?: CallOptions & CallOptionsExt): Promise<WorkerRegisterResponse>;
    listen(request: DeepPartial<WorkerListenRequest>, options?: CallOptions & CallOptionsExt): AsyncIterable<AssignedAction>;
    /**
     * ListenV2 is like listen, but implementation does not include heartbeats. This should only used by SDKs
     * against engine version v0.18.1+
     */
    listenV2(request: DeepPartial<WorkerListenRequest>, options?: CallOptions & CallOptionsExt): AsyncIterable<AssignedAction>;
    /** Heartbeat is a method for workers to send heartbeats to the dispatcher */
    heartbeat(request: DeepPartial<HeartbeatRequest>, options?: CallOptions & CallOptionsExt): Promise<HeartbeatResponse>;
    subscribeToWorkflowEvents(request: DeepPartial<SubscribeToWorkflowEventsRequest>, options?: CallOptions & CallOptionsExt): AsyncIterable<WorkflowEvent>;
    subscribeToWorkflowRuns(request: AsyncIterable<DeepPartial<SubscribeToWorkflowRunsRequest>>, options?: CallOptions & CallOptionsExt): AsyncIterable<WorkflowRunEvent>;
    sendStepActionEvent(request: DeepPartial<StepActionEvent>, options?: CallOptions & CallOptionsExt): Promise<ActionEventResponse>;
    sendGroupKeyActionEvent(request: DeepPartial<GroupKeyActionEvent>, options?: CallOptions & CallOptionsExt): Promise<ActionEventResponse>;
    putOverridesData(request: DeepPartial<OverridesData>, options?: CallOptions & CallOptionsExt): Promise<OverridesDataResponse>;
    unsubscribe(request: DeepPartial<WorkerUnsubscribeRequest>, options?: CallOptions & CallOptionsExt): Promise<WorkerUnsubscribeResponse>;
    refreshTimeout(request: DeepPartial<RefreshTimeoutRequest>, options?: CallOptions & CallOptionsExt): Promise<RefreshTimeoutResponse>;
    releaseSlot(request: DeepPartial<ReleaseSlotRequest>, options?: CallOptions & CallOptionsExt): Promise<ReleaseSlotResponse>;
    upsertWorkerLabels(request: DeepPartial<UpsertWorkerLabelsRequest>, options?: CallOptions & CallOptionsExt): Promise<UpsertWorkerLabelsResponse>;
}
type Builtin = Date | Function | Uint8Array | string | number | boolean | undefined;
export type DeepPartial<T> = T extends Builtin ? T : T extends globalThis.Array<infer U> ? globalThis.Array<DeepPartial<U>> : T extends ReadonlyArray<infer U> ? ReadonlyArray<DeepPartial<U>> : T extends {} ? {
    [K in keyof T]?: DeepPartial<T[K]>;
} : Partial<T>;
export type ServerStreamingMethodResult<Response> = {
    [Symbol.asyncIterator](): AsyncIterator<Response, void>;
};
export interface MessageFns<T> {
    encode(message: T, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): T;
    fromJSON(object: any): T;
    toJSON(message: T): unknown;
    create(base?: DeepPartial<T>): T;
    fromPartial(object: DeepPartial<T>): T;
}
export {};
